@@ -4,11 +4,15 @@ import pathlib
 import sys
 import click
 import traceback
+import tempfile
+import shutil
 
 from honeybee_vtk.model import Model
 from honeybee_vtk.vtkjs.schema import SensorGridOptions, DisplayMode
 from honeybee_vtk.types import ImageTypes
 from honeybee_vtk.text_actor import TextActor
+from honeybee_vtk.timestep_images import export_timestep_images, _extract_periods_colors
+from honeybee_vtk.image_processing import write_gif, write_transparent_images
 
 
 @click.group()
@@ -57,7 +61,7 @@ def export():
     '--grid-display-mode', '-gdm',
     type=click.Choice(['shaded', 'surface', 'surfacewithedges',
                        'wireframe', 'points'], case_sensitive=False),
-    default='surfacewithedges', help='Set display mode for the Sensorgrids.',
+    default='shaded', help='Set display mode for the Sensorgrids.',
     show_default=True
 )
 @click.option(
@@ -76,8 +80,9 @@ def export():
     ' when using this command locally.', show_default=True
 )
 @click.option(
-    '--grid/--model', is_flag=True, default=False, help='Boolean to decide whether to export'
-    ' the images of a whole model or only the grids. Set it to True to export the grids.',
+    '--selection', '-sel',
+    type=click.Choice(['model', 'grid', 'timesteps'], case_sensitive=False),
+    default='model', help='Select what to export.',
     show_default=True
 )
 @click.option(
@@ -86,32 +91,80 @@ def export():
     ' grid identifiers as filters.'
 )
 @click.option(
-    '--text', type=str, default=None, show_default=True, help='Text to be displayed on the'
-    ' image.'
+    '--text', type=str, default=None, show_default=True, help='Text to be displayed on'
+    ' an image of a grid. This will put this same text on all of the images.'
 )
 @click.option(
     '--text-height', '-th', type=int, default=15, show_default=True,
-    help='Set the height of the text in pixels.'
+    help='Set the height of the text in pixels for the text that will be added to the'
+    ' image of a grid.'
 )
 @click.option(
     '--text-color', '-tc', type=(int, int, int), default=(0, 0, 0), show_default=True,
-    help='Set the text color.',
+    help='Set the text color of the text that will added to the image of a grid.'
 )
 @click.option(
     '--text-position', '-tp', type=(float, float), default=(0.5, 0.0), show_default=True,
-    help='Set the text position in the image. The setting is applied at the lower left'
-    ' point of the text. (0,0) will give you the lower left corner of the image.'
-    ' (1,1) will give you the upper right corner of the image.'
+    help='Set the text position of the text to added to the image of a grid. The setting'
+    ' is applied at the lower left point of the text. (0,0) will give you the lower'
+    ' left corner of the image. (1,1) will give you the upper right corner of the image.'
 )
 @click.option(
-    '--text-bold', '-tb', is_flag=True, default=False, show_default=True,
-    help='Set the text to be bold.'
+    '--text-bold/--text-normal', is_flag=True, default=False, show_default=True,
+    help='Set the text to be bold for the text that will added to the image of a grid.'
+)
+@click.option(
+    '--time-step-file-name', '-tfn', type=str, default='', show_default=True,
+    help='Name of the time step file without its extension.'
+)
+@click.option(
+    '--periods-file', '-pf', help='File Path to the Periods json file which can be used'
+    ' to define time periods and colors. A period is composed of two Ladybug DateTime'
+    ' objects. First is the start DateTime and second is the End DateTime. Think of'
+    ' these periods as filters of time steps. Images will be generated for these periods'
+    ' only. You can also define colors for corresponding periods.',
+    type=click.Path(exists=True), default=None, show_default=True
+)
+@click.option(
+    '--flat/--gradient', default=True, show_default=True, help='Indicate'
+    ' whether to use flat transparency or gradient transparency in generating time step'
+    ' images. If flat is chosen, all the images wil have the same level of transparency.'
+    ' If gradient is chosen, the transparency of an image will be lower than the'
+    ' transparency of the image coming above.'
+)
+@click.option(
+    '--transparent-images/--no-images', is_flag=True, default=False, show_default=True,
+    help='Indicate whether to generate transparent images of each timestep or not.'
+)
+@click.option(
+    '--gif-name', '-gn', type=str, default='output', show_default=True,
+    help='Name of the gif file.'
+)
+@click.option(
+    '--gif-duration', '-gd', type=int, default=1000, show_default=True,
+    help='Duration of the gif in milliseconds.'
+)
+@click.option(
+    '--gif-loop-count', '-glc', type=int, default=0, show_default=True,
+    help='Number of times the gif should loop. 0 means infinite.'
+)
+@click.option(
+    '-gif-linger-last-frame', '-gl', type=int, default=3, show_default=True,
+    help='A number that will make the last frame linger for longer than the duration'
+    ' by this multiple.'
+)
+@ click.option(
+    '--image-transparency', '-it', type=float, default=0.5, show_default=True,
+    help='Set the transparency of the image. 0.0 is fully transparent and 1.0 is fully'
+    ' opaque.'
 )
 def export(
         hbjson_file, folder, image_type, image_width, image_height,
         background_color, model_display_mode, grid_options, grid_display_mode, view,
-        config, validate_data, grid, grid_filter, text, text_height, text_color,
-        text_position, text_bold):
+        config, validate_data, selection, grid_filter, text, text_height, text_color,
+        text_position, text_bold, time_step_file_name, periods_file, flat,
+        transparent_images, gif_name, gif_duration, gif_loop_count,
+        gif_linger_last_frame, image_transparency,):
     """Export images from radiance views in a HBJSON file.
 
     \b
@@ -171,7 +224,7 @@ def export(
     try:
         model = Model.from_hbjson(hbjson=hbjson_file, load_grids=grid_options)
 
-        if not grid:
+        if selection.lower() == 'model':
             output = model.to_images(folder=folder, config=config,
                                      validation=validate_data,
                                      model_display_mode=model_display_mode,
@@ -179,7 +232,8 @@ def export(
                                      background_color=background_color, view=view,
                                      image_type=image_type, image_width=image_width,
                                      image_height=image_height,)
-        else:
+
+        elif selection.lower() == 'grid':
             text_actor = TextActor(text=text, height=text_height, color=text_color,
                                    position=text_position, bold=text_bold)\
                 if text else None
@@ -192,6 +246,41 @@ def export(
                                           image_width=image_width,
                                           image_height=image_height,
                                           text_actor=text_actor)
+        else:
+            periods, grid_colors = _extract_periods_colors(periods_file)
+
+            if not config:
+                raise ValueError('Config file not provided.')
+            if not time_step_file_name:
+                raise ValueError('Time step file name not provided.')
+            if not periods:
+                raise ValueError('Periods file not provided.')
+
+            if grid_display_mode == DisplayMode.Points:
+                print('Grids as points are not supported for image export of timesteps.')
+                grid_display_mode = DisplayMode.Shaded
+
+            temp_folder = pathlib.Path(tempfile.mkdtemp())
+            output = export_timestep_images(hbjson_path=hbjson_file, config_path=config,
+                                            timestamp_file_name=time_step_file_name,
+                                            periods=periods, grid_colors=grid_colors,
+                                            grid_display_mode=grid_display_mode,
+                                            target_folder=temp_folder,
+                                            grid_filter=grid_filter,
+                                            text_actor=None,
+                                            label_images=False)
+            if flat:
+                write_gif(output, folder.as_posix(), False, gif_name, gif_duration,
+                          gif_loop_count, gif_linger_last_frame)
+            else:
+                write_gif(output, folder.as_posix(), True, gif_name, gif_duration,
+                          gif_loop_count, gif_linger_last_frame)
+
+            if transparent_images:
+                write_transparent_images(output, folder.as_posix(), image_transparency)
+
+            shutil.rmtree(temp_folder)
+            output = folder
 
     except Exception:
         traceback.print_exc()
