@@ -8,6 +8,7 @@ from pydantic import BaseModel, validator, Field, constr, conint
 from pydantic.types import confloat, conlist
 from .types import DataSetNames
 from .legend_parameter import ColorSets, DecimalCount, Orientation
+from ladybug.dt import DateTime
 
 
 class InputFile(BaseModel):
@@ -185,21 +186,29 @@ class DataConfig(BaseModel):
         ' exported images or not.'
     )
 
+    lower_threshold: Union[Autocalculate, float] = Field(
+        Autocalculate(),
+        description='Lower end of the threshold range for the data. Data beyond this'
+        ' threshold will be filtered. This value is included in the thresholding'
+        ' operation. For example, if you want the lower threshold to filter all the'
+        ' values greater than 0 then set the value to 0.1. If not specified, the lower'
+        ' threshold will be infinite. Defaults to None.'
+    )
+
+    upper_threshold: Union[Autocalculate, float] = Field(
+        Autocalculate(),
+        description='Upper end of the threshold range for the data. Data beyond this'
+        ' threshold will be filtered. This value is included in the thresholding'
+        ' operation. For example, if you want the threshold to filter all the Values'
+        ' less than 1 then set the value to 0.99. If not specified, the upper threshold'
+        ' will be infinite. Defaults to None.'
+    )
+
     legend_parameters: LegendConfig = Field(
         LegendConfig(),
         description='Legend parameters to create legend out of the this dataset.'
     )
 
-    @validator('identifier')
-    def check_space(cls, v: str) -> str:
-        """Check that identifier does not contain spaces.
-
-        This check is needed to make the identifier compliant with Radiance.
-        """
-        if ' ' in v:
-            raise ValueError('Identifier cannot have a blank space.')
-        return v
-
     @validator('legend_parameters')
     def check_pos_against_width_height(cls, v: LegendConfig, values) -> LegendConfig:
         id = values['identifier']
@@ -229,3 +238,39 @@ class Config(BaseModel):
         description='List of data-config objects that define the data to be loaded on'
         ' the model.'
     )
+
+
+class DateTimeConfig(BaseModel):
+    """A DateTime object."""
+    month: conint(ge=1, le=12) = Field(
+        description='Month of the year. Accepted values are between 1 and 12 inclusive.'
+    )
+    day: conint(ge=1, le=31) = Field(
+        description='Month of the year. Accepted values are between 1 and 31 inclusive.'
+    )
+    hour: conint(ge=0, le=23) = Field(
+        description='Hour of the day. Accepted values are between 0 and 23 inclusive.'
+    )
+
+
+class Period(BaseModel):
+    """A period of time for which to generate time step images."""
+
+    date_time: conlist(DateTimeConfig, min_items=2, max_items=2) = Field(
+        description='A list of two DateTimConfig objects that define the start and end'
+        ' of the period. The first DateTime object is the start of the period and'
+        ' the second DateTime object is the end of the period.'
+    )
+    color: conlist((conint(ge=0, le=255)), min_items=3, max_items=3) = Field(
+        [0, 0, 0],
+        description='An array of three integer values representing R, G, and B values'
+        ' for the color of text. Values from 0 to 255 are accepted.'
+    )
+
+
+class Periods(BaseModel):
+    """Config for the peridos to be used in generating time step images."""
+    periods: List[Period] = Field(
+        description='A list of Period objects that define the periods to be used in'
+        ' generating time step images.'
+    )
