@@ -1,9 +1,9 @@
 """Vtk legend parameters."""
 
 import vtk
-from ladybug.color import Colorset
+from ladybug.color import Colorset, Color
 from enum import Enum, auto
-from typing import Tuple, Union
+from typing import Tuple, Union, List
 from ._helper import _validate_input
 
 
@@ -187,7 +187,7 @@ class LegendParameter:
                 title of the legend. Default to "Legend".
             unit: A text string representing the unit of the data that the legend
                 represents. Examples are 'celsius', 'kwn/m2', etc.
-            colors: A Colors object. Defaults to Ecotect colorset.
+            colorset: A ColorSet object. Defaults to Ecotect colorset.
             hide_legend: A boolean to set the visibility of a legend in Scene.
                 Defaults to False.
             orientation: An Orientation object that sets the orientation of the legend in
@@ -231,7 +231,7 @@ class LegendParameter:
             self,
             name: str = 'Legend',
             unit: str = '',
-            colors: ColorSets = ColorSets.ecotect,
+            colorset: ColorSets = ColorSets.ecotect,
             hide_legend: bool = False,
             orientation: Orientation = Orientation.horizontal,
             position: Tuple[float, float] = (0.5, 0.1),
@@ -249,7 +249,7 @@ class LegendParameter:
 
         self.name = name
         self.unit = unit
-        self.colors = colors
+        self.colorset = colorset
         self.hide_legend = hide_legend
         self.orientation = orientation
         self.position = position
@@ -264,6 +264,7 @@ class LegendParameter:
         self.min = min
         self.max = max
         self.auto_range = auto_range
+        self._colors = ()
 
     @property
     def name(self) -> str:
@@ -298,16 +299,16 @@ class LegendParameter:
             )
 
     @property
-    def colors(self) -> ColorSets:
+    def colorset(self) -> ColorSets:
         """Colors to be used in the legend."""
-        return self._colors
+        return self._colorset
 
-    @colors.setter
-    def colors(self, val) -> None:
+    @colorset.setter
+    def colorset(self, val) -> None:
         if not val:
-            self._colors = ColorSets.ecotect
+            self._colorset = ColorSets.ecotect
         elif isinstance(val, ColorSets):
-            self._colors = val
+            self._colorset = val
         else:
             raise ValueError(
                 f'A ColorSet objects expected. Instead got {val}.'
@@ -404,12 +405,12 @@ class LegendParameter:
     def color_count(self, val) -> None:
         if not val:
             self._color_count = None
-        elif isinstance(val, int) and 0 <= val <= len(self.colors.value):
+        elif isinstance(val, int) and 0 <= val <= len(self.colorset.value):
             self._color_count = val
         else:
             raise ValueError(
                 'Color count must be a number less than or equal to the number of'
-                f' colors in the colors property, which is {len(self.colors.value)}.'
+                f' colors in the colors property, which is {len(self.colorset.value)}.'
                 f' Instead got {val}.'
             )
 
@@ -423,12 +424,12 @@ class LegendParameter:
         if not val:
             self._label_count = None
         elif not self._color_count:
-            if isinstance(val, int) and 0 <= val <= len(self.colors.value):
+            if isinstance(val, int) and 0 <= val <= len(self.colorset.value):
                 self._label_count = val
             else:
                 raise ValueError(
                     'Label count must be a number less than or equal to the number of'
-                    f' colors {len(self.colors.value)}. Instead got {val}.'
+                    f' colors {len(self.colorset.value)}. Instead got {val}.'
                 )
         elif self._color_count:
             if isinstance(val, int) and 0 <= val <= self._color_count:
@@ -571,6 +572,15 @@ class LegendParameter:
                     f' value {self._min}.'
                 )
 
+    def _assign_colors(self, colors: Tuple[Color, ...]) -> None:
+        """Assign colors instead of a colorset.
+
+        This private method is currently used in generating timestep images.
+        """
+        self._colors = colors
+        self._color_count = len(colors)
+        self.label_count = self._color_count
+
     def _to_dict(self) -> dict:
         """Get the legend parameters as a dictionary object.
 
@@ -579,7 +589,7 @@ class LegendParameter:
         return {
             'name': self.name,
             'unit': self.unit,
-            'colors': self.colors.value,
+            'colors': self.colorset.value,
             'hide_legend': self.hide_legend,
             'color_count': self.color_count,
             'label_count': self.label_count,
@@ -591,7 +601,10 @@ class LegendParameter:
     def get_lookuptable(self) -> vtk.vtkLookupTable:
         """Get a vtk lookuptable."""
         minimum, maximum = self.range
-        color_values = color_set[self._colors.value]
+        if not self._colors:
+            color_values = color_set[self._colorset.value]
+        else:
+            color_values = self._colors
         lut = vtk.vtkLookupTable()
         lut.SetRange(minimum, maximum)
         lut.SetRampToLinear()
@@ -610,10 +623,10 @@ class LegendParameter:
     def get_scalarbar(self) -> vtk.vtkScalarBarActor:
         """Get a vtk scalar bar (legend)."""
 
-        color_range = self.get_lookuptable()
+        lookup_table = self.get_lookuptable()
 
         scalar_bar = vtk.vtkScalarBarActor()
-        scalar_bar.SetLookupTable(color_range)
+        scalar_bar.SetLookupTable(lookup_table)
 
         if self._unit:
             scalar_bar.SetTitle(f'{self._name} [{self._unit}]')
@@ -652,7 +665,7 @@ class LegendParameter:
             f'Legend name: {self._name} |'
             f' Legend title: {self._unit} |'
             f' Legend visibility: {self._hide_legend} |'
-            f' Legend color scheme: {self._colors.name} |'
+            f' Legend color scheme: {self._colorset.name} |'
             f' Legend orientation: {self._orientation} |'
             f' Legend position: {self._position} |'
             f' Legend width: {self._width} |'
