@@ -54,40 +54,6 @@ DATA_SETS = {
 }
 
 
-def _camera_to_grid_actor(actor: Actor, data_name: str, zoom: int = 2,
-                          auto_zoom: bool = True, camera_offset: int = 3,
-                          clipping_range: Tuple[int, int] = (0, 4), ) -> Camera:
-    """Create a Camera for a grid actor.
-
-    This function uses the center point of a grid actor to create a camera that is
-    setup at the camera_offset distance from the center point.
-
-    Args:
-        actor: An Actor object.
-        data_name: name of the data being loaded on the grid. This is
-            used in naming the image files.
-        zoom: The zoom level of the camera. Defaults to 15.
-        auto_zoom: A boolean to set the camera to auto zoom. Setting this to True will
-            discard the Zoom level. Set this to False to use the zoom level. Defaults to
-            True.
-        camera_offset: The distance between the camera and the sensor grid.
-            Defaults to 100.
-        clipping_range: The clipping range of the camera. Defaults to (100, 101).
-
-    Returns:
-        A Camera object.
-    """
-
-    cent_pt = actor.centroid
-    return Camera(identifier=f'{data_name}_{actor.name}',
-                  position=(cent_pt.x, cent_pt.y, cent_pt.z + camera_offset),
-                  projection='l',
-                  focal_point=cent_pt,
-                  clipping_range=clipping_range,
-                  parallel_scale=zoom,
-                  reset_camera=auto_zoom)
-
-
 class Model(object):
     """A honeybee-vtk model.
 
@@ -618,26 +584,35 @@ class Model(object):
             folder=folder, image_type=image_type,
             image_width=image_width, image_height=image_height)
 
-    def to_grid_images(self,  *, folder: str = '.', config: str,
+    def to_grid_images(self, config: str, *, folder: str = '.',
                        grid_filter: List[str] = None,
                        grid_display_mode: DisplayMode = DisplayMode.SurfaceWithEdges,
                        background_color: Tuple[int, int, int] = None,
                        image_type: ImageTypes = ImageTypes.png,
-                       image_width: int = 0, image_height: int = 0,
-                       text_actor: TextActor = None) -> List[str]:
+                       image_width: int = 0, image_height: int = 0, image_name: str = '',
+                       text_actor: TextActor = None,
+                       grid_camera_dict: Dict[str, vtk.vtkCamera] = None,
+                       extract_camera: bool = False,
+                       grid_color: Color = None,
+                       sub_folder_name: str = None) -> Union[Dict[str, Camera],
+                                                             List[str]]:
         """Export am image for each grid in the model.
 
         Use the config file to specify which grids with which data to export. For
         instance, if the config file has DataConfig objects for 'DA' and 'UDI', and
-        'DA' is kept hidden, then all grids with 'UDI' data will be exported. Additionally,
-        images from a selected number of grids can be exported by using the by
-        specifyling the identifiers of the grids to export in the grid_filter object in
-        the config file.
+        'DA' is kept hidden, then all grids with 'UDI' data will be exported.
+        Additionally, images from a selected number of grids can be exported by
+        using the by specifyling the identifiers of the grids to export in the
+        grid_filter object in the config file.
+
+        Note that the parameters grid_camera_dict and extract_camera are mutually
+        exclusive. If both are provided, the extract_camera will be used and the
+        grid_camera_dict will be ignored.
 
         Args:
+            config: Path to the config file in JSON format.
             folder: Path to the folder where you'd like to export the images. Defaults to
                     the current working directory.
-            config: Path to the config file in JSON format.
             grid_filter: A list of grid identifiers to export images of those grid only.
                 Defaults to None which will export all the grids.
             display_mode: Display mode for the grid. Defaults to surface with edges.
@@ -647,11 +622,26 @@ class Model(object):
                 default radiance view's horizontal angle to derive the width.
             image_height: Image height in pixels. Defaults to 0. Which will use the
                 default radiance view's vertical angle to derive the height.
+            image_name: A text string that sets the name of the image. Defaults to ''.
             text_actor: A TextActor object that defines the properties of the text to be
                 added to the image. Defaults to None.
+            grid_camera_dict: A dictionary of grid identifiers and vtkCamera objects.
+                If provided, the camera objects specified in the dict will be used to
+                export the images. This is useful when a camera from another run is
+                to be used in this run to export an image. Defaults to None.
+            extract_camera: Boolean to indicate whether to extract the camera from the
+                for this run to use for the next run. Defaults to False.
+            grid_color: Color of the grid. This is used to set the color of the grid
+                when exporting the time step images when the whole grid needs to be
+                of a single color. Defaults to None.
+            sub_folder_name: A text string that sets the name of the subfolder where
+                the images will be exported. This is useful when the images are to be
+                exported for multiple time periods such as whole day of June 21, and 
+                the whole day of March, 21. Defaults to None.
 
         Returns:
-            Path to the folder where the images are exported for each grid.
+            Path to the folder where the images are exported for each grid. Or a
+            dictionary of grid identifers and camera objects.
         """
         assert len(self.sensor_grids.data) != 0, 'No sensor grids found in the model.'
 
@@ -659,35 +649,59 @@ class Model(object):
             grid_display_mode = DisplayMode.Points
 
         config_data = self.load_config(config)
+        grid_polydata_lst = filter_grids(self.sensor_grids.data, grid_filter)
 
-        if not grid_filter:
-            grid_polydata_lst = self.sensor_grids.data
-        else:
-            grid_polydata_lst = [grid for grid in self.sensor_grids.data
-                                 if grid.name in grid_filter]
-            if not grid_polydata_lst:
-                raise ValueError('No grids found in the model that match the filter'
-                                 ' defined in the config file.')
+        output: Union[Dict[str, Camera], List[str]] = {} if extract_camera else []
 
-        image_paths: List[str] = []
         for data in config_data:
             for grid_polydata in grid_polydata_lst:
                 dataset = ModelDataSet(name=grid_polydata.identifier,
                                        data=[grid_polydata],
                                        display_mode=grid_display_mode)
+                if grid_color:
+                    dataset.active_field_info.legend_parameter._assign_colors(
+                        (Color(255, 255, 255), grid_color))
                 dataset.color_by = data.identifier
                 actor = Actor(dataset)
+                camera = _camera_to_grid_actor(actor, data.identifier)
                 scene = Scene(background_color=background_color, actors=[actor],
-                              cameras=[_camera_to_grid_actor(actor, data.identifier)],
+                              cameras=[camera],
                               text_actor=text_actor)
                 legend_range = self._get_legend_range(data)
                 self._load_legend_parameters(data, scene, legend_range)
-                image_paths += scene.export_images(folder=folder,
-                                                   image_type=image_type,
-                                                   image_width=image_width,
-                                                   image_height=image_height)
 
-        return image_paths
+                if extract_camera:
+                    vtk_camera = None
+                    output[grid_polydata.identifier] = scene.export_images(
+                        folder=folder, image_type=image_type, image_width=image_width,
+                        image_height=image_height, image_name=image_name,
+                        vtk_camera=vtk_camera, extract_camera=extract_camera
+                    )
+                else:
+                    if grid_camera_dict:
+                        vtk_camera = grid_camera_dict[grid_polydata.identifier]
+                    else:
+                        vtk_camera = None
+
+                    if not sub_folder_name:
+                        grid_folder = pathlib.Path(
+                            f'{folder}/{grid_polydata.identifier}')
+                    else:
+                        grid_folder = pathlib.Path(
+                            f'{folder}/{grid_polydata.identifier}/{sub_folder_name}')
+
+                    if grid_folder.exists():
+                        shutil.rmtree(grid_folder)
+                    grid_folder.mkdir(parents=True, exist_ok=True)
+
+                    output += scene.export_images(folder=grid_folder,
+                                                  image_type=image_type,
+                                                  image_width=image_width,
+                                                  image_height=image_height,
+                                                  image_name=image_name,
+                                                  vtk_camera=vtk_camera)
+
+        return output
 
     @ staticmethod
     def get_default_color(face_type: face_types) -> Color:
@@ -750,7 +764,6 @@ class Model(object):
                         if not folder_path.is_dir():
                             raise FileNotFoundError(
                                 f'No folder found at {data.path}')
-                    identifier = data.identifier
                     grid_type = self._get_grid_type()
                     # Validate data if asked for
                     if validation:
@@ -758,7 +771,7 @@ class Model(object):
                     # get legend range if provided by the user
                     legend_range = self._get_legend_range(data)
                     # Load data
-                    self._load_data(folder_path, identifier, grid_type, legend_range)
+                    self._load_data(data, grid_type, legend_range)
                     # Load legend parameters
                     if legend:
                         self._load_legend_parameters(data, scene, legend_range)
@@ -843,22 +856,31 @@ class Model(object):
                 ' Lengths of files with following names do not match'
                 f' {tuple(names_to_report)}.')
 
-    def _load_data(self, folder_path: pathlib.Path, identifier: str,
-                   grid_type: str, legend_range: List[Union[float, int]]) -> None:
+    def _load_data(self, data: DataConfig, grid_type: str,
+                   legend_range: List[Union[float, int]]) -> None:
         """Load validated data on a honeybee-vtk model.
 
         This is a helper method to the public load_config method.
 
         Args:
-            folder_path: A valid pathlib path to the folder with grid_info.json and data.
-            identifier: A text string representing the identifier of the data in the config
-                file.
+            data (DataConfig): A Dataconfig object.
             model: A honeybee-vtk model.
             grid_type: A string indicating whether the sensor grid in the model is made of
                 points or meshes.
             legend_range: A list of min and max values of the legend parameters provided by
                 the user in the config file.
         """
+        folder_path = pathlib.Path(data.path)
+        identifier = data.identifier
+        if isinstance(data.lower_threshold, float):
+            lower_threshold = data.lower_threshold
+        else:
+            lower_threshold = None
+        if isinstance(data.upper_threshold, float):
+            upper_threshold = data.upper_threshold
+        else:
+            upper_threshold = None
+
         grids_info_json = folder_path.joinpath('grids_info.json')
         with open(grids_info_json) as fh:
             grids_info = json.load(fh)
@@ -886,12 +908,14 @@ class Model(object):
         ds = self.get_modeldataset(DataSetNames.grid)
 
         if grid_type == 'meshes':
-            ds.add_data_fields(
-                result, name=identifier, per_face=True, data_range=legend_range)
+            ds.add_data_fields(result, name=identifier, per_face=True,
+                               data_range=legend_range, lower_threshold=lower_threshold,
+                               upper_threshold=upper_threshold)
             ds.color_by = identifier
         else:
-            ds.add_data_fields(
-                result, name=identifier, per_face=False, data_range=legend_range)
+            ds.add_data_fields(result, name=identifier, per_face=False,
+                               data_range=legend_range, lower_threshold=lower_threshold,
+                               upper_threshold=upper_threshold)
             ds.color_by = identifier
 
     @ staticmethod
@@ -935,8 +959,7 @@ class Model(object):
 
         legend_params = data.legend_parameters
         legend = scene.legend_parameter(data.identifier)
-
-        legend.colors = legend_params.color_set
+        legend.colorset = legend_params.color_set
         legend.unit = data.unit
         if legend_range:
             legend.min, legend.max = legend_range
@@ -969,3 +992,59 @@ class Model(object):
         title_params = legend_params.title_parameters
         legend.title_parameters = Text(
             title_params.color, title_params.size, title_params.bold)
+
+
+def _camera_to_grid_actor(actor: Actor, data_name: str, zoom: int = 2,
+                          auto_zoom: bool = True, camera_offset: int = 3,
+                          clipping_range: Tuple[int, int] = (0, 4), ) -> Camera:
+    """Create a Camera for a grid actor.
+
+    This function uses the center point of a grid actor to create a camera that is
+    setup at the camera_offset distance from the center point.
+
+    Args:
+        actor: An Actor object.
+        data_name: name of the data being loaded on the grid. This is
+            used in naming the image files.
+        zoom: The zoom level of the camera. Defaults to 2.
+        auto_zoom: A boolean to set the camera to auto zoom. Setting this to True will
+            discard the Zoom level. Set this to False to use the zoom level. Defaults to
+            True.
+        camera_offset: The distance between the camera and the sensor grid.
+            Defaults to 100.
+        clipping_range: The clipping range of the camera. Defaults to (100, 101).
+
+    Returns:
+        A Camera object.
+    """
+
+    cent_pt = actor.centroid
+    return Camera(identifier=f'{data_name}_{actor.name}',
+                  position=(cent_pt.x, cent_pt.y, cent_pt.z + camera_offset),
+                  projection='l',
+                  focal_point=cent_pt,
+                  clipping_range=clipping_range,
+                  parallel_scale=zoom,
+                  reset_camera=auto_zoom)
+
+
+def filter_grids(grid_polydata_lst: List[PolyData],
+                 grid_filter: List[str]) -> List[PolyData]:
+    """Filter grids based on the grid_filter.
+
+    Args:
+        grid_polydata_lst: A list of PolyData objects for Grids.
+        grid_filter: A list of grid identifiers to filter grids.
+
+    Returns:
+        A list of PolyData objects for Grids.
+    """
+    if not grid_filter:
+        return grid_polydata_lst
+    else:
+        filtered_grid_polydata_lst = [grid for grid in grid_polydata_lst
+                                      if grid.name in grid_filter]
+        if not filtered_grid_polydata_lst:
+            raise ValueError('No grids found in the model that match the filter'
+                             ' defined in the config file.')
+        return filtered_grid_polydata_lst
